aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorschnetter <schnetter@83718e91-0e4f-0410-abf4-91180603181f>2008-02-03 17:00:24 +0000
committerschnetter <schnetter@83718e91-0e4f-0410-abf4-91180603181f>2008-02-03 17:00:24 +0000
commit17d90ff9d56250586ff3153293ee640bff419e84 (patch)
tree4412af9138c5d7a1d1b244c90800e88e206e399c
parente4a5e014618e687a43146c45f07999948421e6d3 (diff)
Output simulation id and run id to metadata storage
git-svn-id: http://svn.cactuscode.org/arrangements/CactusUtils/Formaline/trunk@151 83718e91-0e4f-0410-abf4-91180603181f
-rw-r--r--src/announce.cc37
1 files changed, 36 insertions, 1 deletions
diff --git a/src/announce.cc b/src/announce.cc
index 7edf348..f800921 100644
--- a/src/announce.cc
+++ b/src/announce.cc
@@ -99,10 +99,29 @@ namespace Formaline
if (verbose) CCTK_INFO ("Announcing initial meta information");
if (create_id_files) {
// Create files from the build, run, and simulation ids
// (This shows what jobs were run in the output directory)
{
ostringstream filenamebuf;
+ filenamebuf << out_dir << "/formaline-" << get_config_id (cctkGH);
+ string const filenamestring = filenamebuf.str();
+ ofstream fil;
+ fil.open (filenamestring.c_str(), ios::trunc);
+ fil << get_config_id (cctkGH) << endl;
+ fil.close ();
+ }
+ {
+ ostringstream filenamebuf;
+ filenamebuf << out_dir << "/formaline-" << get_source_id (cctkGH);
+ string const filenamestring = filenamebuf.str();
+ ofstream fil;
+ fil.open (filenamestring.c_str(), ios::trunc);
+ fil << get_source_id (cctkGH) << endl;
+ fil.close ();
+ }
+ {
+ ostringstream filenamebuf;
filenamebuf << out_dir << "/formaline-" << get_build_id (cctkGH);
string const filenamestring = filenamebuf.str();
ofstream fil;
@@ -341,6 +360,14 @@ namespace Formaline
// Compiling
{
+ stores.store ("config_id", get_config_id (cctkGH));
+ }
+
+ {
+ stores.store ("source_id", get_source_id (cctkGH));
+ }
+
+ {
stores.store ("build_id", get_build_id (cctkGH));
}
@@ -365,6 +392,14 @@ namespace Formaline
// Running
+ {
+ stores.store ("simulation_id", get_simulation_id (cctkGH));
+ }
+
+ {
+ stores.store ("run_id", get_run_id (cctkGH));
+ }
+
#if 0
{
char const * const run_user = CCTK_RunUser();
@@ -99,10 +99,29 @@ namespace Formaline
if (verbose) CCTK_INFO ("Announcing initial meta information");
if (create_id_files) {
- // Create files from the build, run, and simulation ids
+ // Create files from the configuration, source, build, run, and
+ // simulation ids
// (This shows what jobs were run in the output directory)
{